/******************************************************************************
 * @file     DMA.c
 * @brief    Configure DMA of 
 *           for the Infineon XMC4500 Device Series
 *           Verwendung der 12 verfgbaren DMA Kanle
 *           +----------------------------------------------------------------------------------+
 *           + Interrupt	   + INTR Node   + DLR Line  + DMA    +	Channel +	                    +
 *           +----------------------------------------------------------------------------------+
 *           + frei          + frei        + 0         + GPDMA0 +	0	      *   
 *           + frei          + frei        + 1         + GPDMA0 +	1	      *   
 *           + SPI Bus RX    + USIC0_1     + 2         + GPDMA0 +	2	      * Transfer Finished Intr   
 *           + frei          + frei        + 3         + GPDMA0 +	3	      *  
 *           + SPI Bus TX    + USIC0_0     + 4         + GPDMA0 +	4	      *     
 *           + frei          + frei        + 5         + GPDMA0 +	5	      *   
 *           + frei          + frei        + 6         + GPDMA0 +	6	      *   
 *           + frei          + frei        + 7         + GPDMA0 +	7	      * 
 *           +----------------------------------------------------------------------------------+-----------------------------+
 * @version  V1.0.0
 * @date     21. Mai 2015
 *
 ******************************************************************************/
#include "basic_typedef.h"
#include "dma.h"

extern void NVICEnableDMA0_Irq (void);
extern void NVICEnableDMA1_Irq (void);

void InitGPDMA0 () {
	// SPI Bus TX GPDMA0
	// SPI Bus TX GPDMA0
	// fdma = fcpu
	// Deassert Reset DMA1
	SCU_RESET->PRSET2 |= 0x0010UL;
	SCU_RESET->PRCLR2 |= 0x0010UL;

	// DMACFGREG: DMA Enable
	GPDMA0->DMACFGREG = 0x0001UL; 

  NVICEnableDMA0_Irq();	
}

// uses GPDMA0 Channel 4
void ProgramGPDMASpiTx (volatile void *src, void *dst, volatile unsigned int length, volatile unsigned int srcchange) {
	unsigned int srcinc;
	
  while (GPDMA0->CHENREG   & 0x0010UL)
		;	// Wait for DMA to be free
  
	// Source Address Register Register
	GPDMA0_CH4->SAR = (unsigned int) src; // Memory Address SPI Sendbuffer

	// Destination Address Register
	GPDMA0_CH4->DAR = (unsigned int) dst; // Memory Address USIC TBUF
	
	// CTLH Control Register High
	// Block Transfer Size (write): Anzahl an Bytes die zu bertragen sind 0-4095
	// Done Bit (read): bertragung abgeschlossen
	GPDMA0_CH4->CTLH = length;
	
	// CTLL Control Register Low
  // INT_EN: Global Intr Mask
	// Destination Transfer Width: 000 = 8 Bit
	// Source Transfer Width: 000 = 8 Bit
	// Destination Address Increment: 00 = Increment, 10 No Change
	// Source Address Increment: 00 = Increment, 10 No Change
  // Dest Transaction Memsize: 000 = 1 Data Item
  // Src  Transaction Memsize: 000 = 1 Data Item
  // Transfer Type: 001 Memory to Peripheral, 010 Peripheral to Memory, 000 Memory to Memory
  if (srcchange == SPITXSRCINC) {
	  srcinc = 0;
	}
	else {
	  srcinc = 2;
	}
  
	GPDMA0_CH4->CTLL = ((1  << 20) |    // Transfer Type Memory to Peripheral
                      (0  << 14) |    // Src Transaction Memsize 1 Data Item	
                      (0  << 11) |	  // Dst Transaction Memsize 1 Data Item
                      (srcinc  <<  9) |    // Source Address Increment	
                      (2  <<  7) |	  // Dest Address No Change
                      (0  <<  4) |    // Source Transfer Width 8 Bit	 
                      (0  <<  1) |	  // Dest Transfer Width 8 Bit
											(0  <<  0)  );  // Global Intr Mask
	// CFGH Control Register High
	// Dest Peripheral DLR Line 4
	// Src  Peripheral DLR Line 0
	GPDMA0_CH4->CFGH =  ((4 << 11) |    // Destination Peripheral
	                     (0 <<  7) |    // Source Peripheral
	                     (0x0004UL) );  // Default Value after Reset
	// CFGL Control Register Low
  GPDMA0_CH4->CFGL = ((1 << 11) |  // Source Handshaking Select 0..Hardware, 1.. Software  Source = Memory, daher 1 
	                    (0 << 10) |  // Destination Handshaking Select 0..Hardware, 1.. Software Dest ist Peripheral, daher 0
											(4 <<  5) ); // Priority : -> Default = Channel Number
	
	// DMA Line Router GPDMA Line 4
	// Interrupt Node = USIC0_SR0  DLR RS4 = 1011B = 0xB
	// DLR_SRSEL0 RS4 = 0110B
	DLR->SRSEL0 = (DLR->SRSEL0 & 0xFFF0FFFFUL) | 0xB0000UL;  // Line 4 Connected to USIC0_SR0
	
	// DLR_LNEN Enable Line 4
	DLR->LNEN |= 0x0010UL;
}

void StartGPDMASpiTx (void) {
		// GPDMA0 Channel Enable Register: Enable Channel 0
  GPDMA0->CHENREG   = 0x1010UL;
}

// uses GPDMA0 Channel 2
void ProgramGPDMASpiRx (volatile void *src, void *dst, volatile unsigned int length, volatile unsigned int dstchange) {
	unsigned int dstinc;

  while (GPDMA0->CHENREG   & 0x0004UL)
		;	// Wait for DMA to be free
  
	// Source Address Register Register
	GPDMA0_CH2->SAR = (unsigned int) src; // Memory Address USIC RBUF

	// Destination Address Register
	GPDMA0_CH2->DAR = (unsigned int) dst; // Memory Address SPI Receivebuffer
	
	// CTLH Control Register High
	// Block Transfer Size (write): Anzahl an Bytes die zu bertragen sind 0-4095
	// Done Bit (read): bertragung abgeschlossen
	GPDMA0_CH2->CTLH = length;
	
	// CTLL Control Register Low
  // INT_EN: Global Intr Mask
	// Destination Transfer Width: 000 = 8 Bit
	// Source Transfer Width: 000 = 8 Bit
	// Destination Address Increment: 00 = Increment, 10 No Change
	// Source Address Increment: 00 = Increment, 10 No Change
  // Dest Transaction Memsize: 000 = 1 Data Item
  // Src  Transaction Memsize: 000 = 1 Data Item
  // Transfer Type: 001 Memory to Peripheral, 010 Peripheral to Memory, 000 Memory to Memory
  if (dstchange == SPIRXDSTINC) {
	  dstinc = 0;
	}
	else {
	  dstinc = 2;
	}
  
	GPDMA0_CH2->CTLL = ((2  << 20) |    // Transfer Type Memory to Peripheral
                      (0  << 14) |    // Src Transaction Memsize 1 Data Item	
                      (0  << 11) |	  // Dst Transaction Memsize 1 Data Item
                      (2  <<  9) |    // Source Address No Change	
                      (dstinc  <<  7) |	  // Dest Address Increment
                      (0  <<  4) |    // Source Transfer Width 8 Bit	 
                      (0  <<  1) |	  // Dest Transfer Width 8 Bit
											(1  <<  0)  );  // Global Intr Mask
	// CFGH Control Register High
	// Dest Peripheral DLR Line 2
	
	GPDMA0_CH2->CFGH = ((0 << 11) |    // Destination Peripheral
	                    (2 <<  7) |    // Source Peripheral
	                    (0x0004UL) );  // Default Value after Reset
											 
	// CFGL Control Register Low
  GPDMA0_CH2->CFGL = ((0 << 11) |  // Source Handshaking Select 0..Hardware, 1.. Software  Source = Peripheral, daher 0 
	                    (1 << 10) |  // Destination Handshaking Select 0..Hardware, 1.. Software Dest ist Memory, daher 1
											(0 <<  5) ); // Priority : -> Default = Channel Number
	
	// DMA Line Router GPDMA Line 2
	// Interrupt Node = USIC0_SR1  DLR RS2 = 1011B
	DLR->SRSEL0 = (DLR->SRSEL0 & 0xFFFFF0FFUL) | 0x0B00UL;  // Line 2 Connected to USIC0_SR1
	
	// DLR_LNEN Enable Line 2
	DLR->LNEN |= 0x0004UL;
	
	// CH2 Transfer Complete Event fr Intr freigeben 
	GPDMA0->MASKTFR = 0x0404UL;
}

void StartGPDMASpiRx (void) {
		// GPDMA0 Channel Enable Register: Enable Channel 0
  GPDMA0->CHENREG   = 0x0404UL;
}

UINT32 g_ui32DMA0_IRQs = 0;
UINT32 g_ui32DMA0_Errors = 0;

extern void U0C0RecTransComplete (void); // from U0C0_SPI_Memory.c

// GPDMA0_0_IRQHandler
void GPDMA0_0_IRQHandler () {
	// Channel 2 Transfer Complete (U0C0 SPI Memory)
	if (GPDMA0->STATUSTFR & 0x0004UL) {
		U0C0RecTransComplete ();
		GPDMA0->CLEARTFR = 0x0004UL;
	}
	
	if (GPDMA0->STATUSERR) {
		GPDMA0->CLEARERR = GPDMA0->STATUSERR;
		g_ui32DMA0_Errors++;
		set_linkled(TRUE);
	}
	g_ui32DMA0_IRQs++;
}
