/*
	Copyright (c) 2015, E.C.E. Wurmitzer GmbH.
	All rights reserved.
*/
/*	Function description

	EBU initialisation for XMC4500-1024 (LQFP144 package)
	
	Chip select regions (only start addresses of real connected devices are valid!):
	CS0			(address 0x60000000 - 0x61FFFFFF                          ):    32 MByte NOR-Flash	(M29W256GL70ZS6)    (Size 0x2000000) Read 16 Zyklen, Write 13 Zyklen
	CS1			(DataReg 0x64000000, AddrReg 0x64020000, CmdReg 0x64040000):   256 MByte NAND-Flash	(S34ML02G104TF1010)                  Read 13 Zyklen, Write  7 Zyklen
	CS2			(address 0x68000000 - 0x681FFFFF                          ):     2 MByte SRAM			  (IS61WV102416BLL)   (Size 0x0200000) Read  7 Zyklen, Write  7 Zyklen
	CS3			(address 0x6C000000 - 0x6CFFFFFF                          ):   2*8 MByte PSRAM1		  (IS66WVE4M16BLL)    (Size 0x1000000) Read 14 Zyklen, Write 12 Zyklen

  Internal ROM:
	Interner Flash 0x80000000 - 0x800FFFFF (Size 0x100000)   cached Read 7 Zyklen, Write 7 Zyklen
  Interner Flash 0x80000000 - 0x800FFFFF (Size 0x100000) uncached Read 7 Zyklen, Write 7 Zyklen 

	Internal RAM:
	   			(address 0x00000000 - 0x00003FFF                          ):     16 KB Internal Boot ROM (PMU ROM)  (Size 0x04000)
			 ===(address 0x08000000 - 0x080FFFFF                          ):      1 MB Internal ROM PMU/FLASH (cached)  (Size 0x100000)
			 ===(address 0x0C000000 - 0x080FFFFF                          ):      1 MB Internal ROM PMU/FLASH (uncached)  (Size 0x100000)
	   			(address 0x10000000 - 0x1000FFFF                          ):     64 KB Internal RAM PSRAM (code)  (Size 0x10000)
					(address 0x20000000 - 0x2000FFFF                          ):     64 KB Internal RAM DSRAM1 (system)  (Size 0x10000)
					(address 0x30000000 - 0x30007FFF                          ):     64 KB Internal RAM DSRAM2 (comm)  (Size 0x08000)

-----------
	Geplante Datenaufteilung:
	0x10000000	Internal PSRAM (code) 		- Reserve
	0x20000000	Internal DSRAM1 (system) 	- RTOS 
	0x30000000	Internal DSRAM2 (comm) 		- USB + ETH (Lt. Infineon Manual Vorschlag)
	0x68000000 	SRAM 											- Daten Rest
	0x6C000000	PSRAM 										- FAT-FS

*/
/*
	File Name:		EBU_Tas400Cpu.c
	Target Device:	Infineon XMC4500-1024
	Created by:		Edmund Titz
	Created on:		2015-04-07
	derived from:	Template.c V2
*/
/*	History

	2015-04-07	V1	EdTi
		- creation of file based on example files from infineon
		  and by using the definitions from "XMC4500.h" file
		  from infineon.
		  
	2015-04-10	V2	EdTi
		- bugfix: corrected entry of EBU->MODCON.ARBMODE from 0 to 3
		
	2015-04-12	V3	EdTi
		- changed some timings requested by NiP

*/	

/*	todo-list

	-check/compare EBU configuration with timing diagrams from NiP [OPEN]

*/

/*
	Includes
*/
#include "basic_typedef.h"

/*
	Port pin definitions
*/
//All predefinitions of port-pins are done in "PortIOconfTas400Cpu.c".
//So the port configuration must be executed before the EBU init!

/*
	Macros / Defines
*/


/*
	External Variables Protoypes
*/


/*
	External Function Header Prototypes
*/
	void EBU_Init(void);

/*
	Public Variables
*/

/*
	Static Variables
*/

/*
	Private Function Prototypes
*/


/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
*/

/*
// <h> EBU (EdTi: This wizard only includes some parts of the EBU registers to simplify changes during test!)
*/

/*
// ---------------- EBU CLC Reg --------------------------------------------------
// <h> EBU Clock Control Register (CLC)
//    <o> Disable Request Bit (DISR)
//       <0x00=> EBU disable is not requested
//       <0x01=> EBU disable is requested


//    <i> Used for: Enable/disable control of the EBU
//    <i> Default: "EBU disable is not requested"
*/
#define EBU_CLC_DISR_VAL (0U)

/*
//    <o> Clock Divide Ratio (EBUDIV)
//       <0x00=> Request EBU to run with input clock 
//       <0x01=> Request EBU to run with input clock devided by 2
//       <0x02=> Request EBU to run with input clock devided by 3
//       <0x03=> Request EBU to run with input clock devided by 4

//    <i> Used for: EBU input clock divider
//    <i> Default: "Request EBU to run off input clock"
*/
#define EBU_CLC_EBUDIV_VAL (0U)

// 		</h>

/*
//-------- <<< end of configuration section >>> ------------------
*/


/*  Function to Initialize EBU Registers
 */
void EBU_Init(void)
{	
	/* Deassert EBU */
	SCU_RESET->PRCLR3 = SCU_RESET_PRCLR3_EBURS_Msk;//EBU Reset clear

	/* Do not setup the EBU Global registers if it is already initialized */
	if(!(EBU->MODCON & EBU_MODCON_ARBMODE_Msk))
	{ 
	//!!first do the portpin configuration!!
		
/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	/*!< (@ 0x58008000) EBU Clock Control Register                             */
		EBU->CLC =		(	((uint32_t)(EBU_CLC_DISR_VAL  	<<  EBU_CLC_DISR_Pos) 			& EBU_CLC_DISR_Msk)				/*EBU disable request  			rw*/| \
							/*((uint32_t)(0U  				<<  EBU_CLC_DISS_Pos) 			& EBU_CLC_DISS_Msk)				  EBU disable status			r| \*/
							((uint32_t)(1U  				<<  EBU_CLC_SYNC_Pos) 			& EBU_CLC_SYNC_Msk)				/*EBU run sync to ARM  			rw*/| \
							((uint32_t)(0U  				<<  EBU_CLC_DIV2_Pos) 			& EBU_CLC_DIV2_Msk)				/*EBU run AHB clock/2  			rw*/| \
							((uint32_t)(EBU_CLC_EBUDIV_VAL	<<  EBU_CLC_EBUDIV_Pos) 		& EBU_CLC_EBUDIV_Msk)			/*EBU run clk /2,/3,/4 			rw|*/ \
							/*((uint32_t)(1U  				<<  EBU_CLC_SYNCACK_Pos) 		& EBU_CLC_SYNCACK_Msk)			  EBU run sync to AHB  			r| \*/
							/*((uint32_t)(0U  				<<  EBU_CLC_DIV2ACK_Pos) 		& EBU_CLC_DIV2ACK_Msk)			  EBU run AHB clock/2  			r| \*/
							/*((uint32_t)(0U  				<<  EBU_CLC_EBUDIVACK_Pos)		& EBU_CLC_EBUDIVACK_Msk)		  EBU run clk /2,/3,/4 			r 	\*/
						);
												   
	/*!< (@ 0x58008004) EBU Configuration Register                             */
		EBU->MODCON =	(	/*((uint32_t)(0U  				<<  EBU_MODCON_STS_Pos) 		& EBU_MODCON_STS_Msk)			  EBU memory status bit #WAIT  	r| \*/
							/*((uint32_t)(0U  				<<  EBU_MODCON_LCKABRT_Pos) 	& EBU_MODCON_LCKABRT_Msk)		  EBU lock abort (reserved) 	r| \*/
							((uint32_t)(1U  				<<  EBU_MODCON_SDTRI_Pos) 		& EBU_MODCON_SDTRI_Msk)			/*EBU SDRAM tristate  			rw*/| \
							((uint32_t)(0U  				<<  EBU_MODCON_EXTLOCK_Pos) 	& EBU_MODCON_EXTLOCK_Msk)		/*EBU external bus lock  		rw*/| \
							((uint32_t)(1U  				<<  EBU_MODCON_ARBSYNC_Pos) 	& EBU_MODCON_ARBSYNC_Msk)		/*EBU arbitration asynchronous  rw*/| \
							((uint32_t)(3U  				<<  EBU_MODCON_ARBMODE_Pos) 	& EBU_MODCON_ARBMODE_Msk)		/*EBU arbitration mode			rw*/| \
							((uint32_t)(0U  				<<  EBU_MODCON_TIMEOUTC_Pos) 	& EBU_MODCON_TIMEOUTC_Msk)		/*EBU timeout					rw*/| \
							((uint32_t)(0U  				<<  EBU_MODCON_LOCKTIMEOUT_Pos)	& EBU_MODCON_LOCKTIMEOUT_Msk)	/*EBU lock timeout (reserved)	rw*/| \
							((uint32_t)(0U  				<<  EBU_MODCON_GLOBALCS_Pos) 	& EBU_MODCON_GLOBALCS_Msk)		/*EBU global ChipSel(no FX)		rw*/| \
							((uint32_t)(0U  				<<  EBU_MODCON_ACCSINH_Pos) 	& EBU_MODCON_ACCSINH_Msk)		/*EBU access inhibit (reserved)	rw*/| \
							/*((uint32_t)(0U  				<<  EBU_MODCON_ACCSINHACK_Pos) 	& EBU_MODCON_ACCSINHACK_Msk)	  EBU ac inhibit ack (reserved)	r| \*/
							((uint32_t)(0U  				<<  EBU_MODCON_ALE_Pos) 		& EBU_MODCON_ALE_Msk)			/*EBU ALE Mode (#ADV)			rw*/ \
						);                            

	/*!< (@ 0x58008008) EBU Module Identification Register                     */
	//	EBU->ID =		(	/*((uint32_t)(?U  				<<  EBU_ID_MOD_REV_Pos) 		& EBU_ID_MOD_REV_Msk)			  EBU Module revision			r| \*/
	//						/*((uint32_t)(0xC0  			<<  EBU_ID_MOD_TYPE_Pos) 		& EBU_ID_MOD_TYPE_Msk)			  EBU Module type (fix 0xC0)	r| \*/
	//						/*((uint32_t)(?U  				<<  EBU_ID_MOD_NUMBER_Pos) 		& EBU_ID_MOD_NUMBER_Msk)		  EBU Module ident number 		r \*/
	//					);

	/*!< (@ 0x5800800C) EBU Test/Control Configuration Register                */
		EBU->USERCON =	(	((uint32_t)(0U  				<<  EBU_USERCON_DIP_Pos) 		& EBU_USERCON_DIP_Msk)			/*EBU Dis int. pipel.(reserved)	rw*/| \
							((uint32_t)(0U  				<<  EBU_USERCON_ADDIO_Pos) 		& EBU_USERCON_ADDIO_Msk)		/*EBU Addr. pins to GPIO		rw*/| \
							((uint32_t)(0U  				<<  EBU_USERCON_ADVIO_Pos) 		& EBU_USERCON_ADVIO_Msk)		/*EBU Addr. valid(#ADV) to GPIO	rw*/ \
						);                         

	/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	 //EBU->RESERVED0[2];

	/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	/*!< (@ 0x58008018) EBU Address Select Register 0                          */
		EBU->ADDRSEL0 =	(	((uint32_t)(1U  				<<  EBU_ADDRSEL0_REGENAB_Pos) 	& EBU_ADDRSEL0_REGENAB_Msk)		/*EBU Memory region enable		rw*/| \
							((uint32_t)(0U  				<<  EBU_ADDRSEL0_ALTENAB_Pos) 	& EBU_ADDRSEL0_ALTENAB_Msk)		/*EBU Alternate region enable	rw*/| \
							((uint32_t)(0U  				<<  EBU_ADDRSEL0_WPROT_Pos) 	& EBU_ADDRSEL0_WPROT_Msk)		/*EBU Mem. region write protect	rw*/ \
						);                          

	/*!< (@ 0x5800801C) EBU Address Select Register 1                          */
		EBU->ADDRSEL1 =	(	((uint32_t)(1U  				<<  EBU_ADDRSEL1_REGENAB_Pos) 	& EBU_ADDRSEL1_REGENAB_Msk)		/*EBU Memory region enable		rw*/| \
							((uint32_t)(0U  				<<  EBU_ADDRSEL1_ALTENAB_Pos) 	& EBU_ADDRSEL1_ALTENAB_Msk)		/*EBU Alternate region enable	rw*/| \
							((uint32_t)(0U  				<<  EBU_ADDRSEL1_WPROT_Pos) 	& EBU_ADDRSEL1_WPROT_Msk)		/*EBU Mem. region write protect	rw*/ \
						);                         

	/*!< (@ 0x58008020) EBU Address Select Register 2                          */
		EBU->ADDRSEL2 =	(	((uint32_t)(1U  				<<  EBU_ADDRSEL2_REGENAB_Pos) 	& EBU_ADDRSEL2_REGENAB_Msk)		/*EBU Memory region enable		rw*/| \
							((uint32_t)(0U  				<<  EBU_ADDRSEL2_ALTENAB_Pos) 	& EBU_ADDRSEL2_ALTENAB_Msk)		/*EBU Alternate region enable	rw*/| \
							((uint32_t)(0U  				<<  EBU_ADDRSEL2_WPROT_Pos) 	& EBU_ADDRSEL2_WPROT_Msk)		/*EBU Mem. region write protect	rw*/ \
						);                          

	/*!< (@ 0x58008024) EBU Address Select Register 3                          */
		EBU->ADDRSEL3 =	(	((uint32_t)(1U  				<<  EBU_ADDRSEL3_REGENAB_Pos) 	& EBU_ADDRSEL3_REGENAB_Msk)		/*EBU Memory region enable		rw*/| \
							((uint32_t)(0U  				<<  EBU_ADDRSEL3_ALTENAB_Pos) 	& EBU_ADDRSEL3_ALTENAB_Msk)		/*EBU Alternate region enable	rw*/| \
							((uint32_t)(0U  				<<  EBU_ADDRSEL3_WPROT_Pos) 	& EBU_ADDRSEL3_WPROT_Msk)		/*EBU Mem. region write protect	rw*/ \
						);                          

	/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	/*!< (@ 0x58008028) EBU Bus Configuration Register                         */
		EBU->BUSRCON0 =	(	((uint32_t)(0U  				<<  EBU_BUSRCON0_FETBLEN_Pos) 	& EBU_BUSRCON0_FETBLEN_Msk)		/*EBU Burst length (sync. dev.)	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_FBBMSEL_Pos) 	& EBU_BUSRCON0_FBBMSEL_Msk)		/*EBU Burst buf len => FETBLEN	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_BFSSS_Pos) 	& EBU_BUSRCON0_BFSSS_Msk)		/*EBU Read single stage sync	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_FDBKEN_Pos) 	& EBU_BUSRCON0_FDBKEN_Msk)		/*EBU Burst flash clk feedback	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON0_BFCMSEL_Pos) 	& EBU_BUSRCON0_BFCMSEL_Msk)		/*EBU Burst flash clk mode		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_NAA_Pos) 		& EBU_BUSRCON0_NAA_Msk)			/*EBU EN flash non-array access	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON0_ECSE_Pos) 		& EBU_BUSRCON0_ECSE_Msk)		/*EBU Early ChipSel=>sync burst	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON0_EBSE_Pos) 		& EBU_BUSRCON0_EBSE_Msk)		/*EBU Early #ADV for sync burst	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_DBA_Pos) 		& EBU_BUSRCON0_DBA_Msk)			/*EBU DIS burst addr. wrapping	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_WAITINV_Pos) 	& EBU_BUSRCON0_WAITINV_Msk)		/*EBU Reversed polarity at WAIT	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_BCGEN_Pos) 	& EBU_BUSRCON0_BCGEN_Msk)		/*EBU Byte control sig.(timing)	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON0_PORTW_Pos) 	& EBU_BUSRCON0_PORTW_Msk)		/*EBU Device addressing mode	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_WAIT_Pos) 		& EBU_BUSRCON0_WAIT_Msk)		/*EBU External WAIT control		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_AAP_Pos) 		& EBU_BUSRCON0_AAP_Msk)			/*EBU Async address phase		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON0_AGEN_Pos) 		& EBU_BUSRCON0_AGEN_Msk)		/*EBU Device type for region	rw*/ \
						);                         

	/*!< (@ 0x58008038) EBU Bus Configuration Register                         */
		EBU->BUSRCON1 =	(	((uint32_t)(0U  				<<  EBU_BUSRCON1_FETBLEN_Pos) 	& EBU_BUSRCON1_FETBLEN_Msk)		/*EBU Burst length (sync. dev.)	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_FBBMSEL_Pos) 	& EBU_BUSRCON1_FBBMSEL_Msk)		/*EBU Burst buf len => FETBLEN	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_BFSSS_Pos) 	& EBU_BUSRCON1_BFSSS_Msk)		/*EBU Read single stage sync	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_FDBKEN_Pos) 	& EBU_BUSRCON1_FDBKEN_Msk)		/*EBU Burst flash clk feedback	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON1_BFCMSEL_Pos) 	& EBU_BUSRCON1_BFCMSEL_Msk)		/*EBU Burst flash clk mode		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_NAA_Pos) 		& EBU_BUSRCON1_NAA_Msk)			/*EBU EN flash non-array access	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON1_ECSE_Pos) 		& EBU_BUSRCON1_ECSE_Msk)		/*EBU Early ChipSel=>sync burst	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON1_EBSE_Pos) 		& EBU_BUSRCON1_EBSE_Msk)		/*EBU Early #ADV for sync burst	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_DBA_Pos) 		& EBU_BUSRCON1_DBA_Msk)			/*EBU DIS burst addr. wrapping	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_WAITINV_Pos) 	& EBU_BUSRCON1_WAITINV_Msk)		/*EBU Reversed polarity at WAIT	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_BCGEN_Pos) 	& EBU_BUSRCON1_BCGEN_Msk)		/*EBU Byte control sig.(timing)	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON1_PORTW_Pos) 	& EBU_BUSRCON1_PORTW_Msk)		/*EBU Device addressing mode	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_WAIT_Pos) 		& EBU_BUSRCON1_WAIT_Msk)		/*EBU External WAIT control		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON1_AAP_Pos) 		& EBU_BUSRCON1_AAP_Msk)			/*EBU Async address phase		rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSRCON1_AGEN_Pos) 		& EBU_BUSRCON1_AGEN_Msk)		/*EBU Device type for region	rw*/ \
						);
						
	/*!< (@ 0x58008048) EBU Bus Configuration Register                         */
		EBU->BUSRCON2 =	(	((uint32_t)(0U  				<<  EBU_BUSRCON2_FETBLEN_Pos) 	& EBU_BUSRCON2_FETBLEN_Msk)		/*EBU Burst length (sync. dev.)	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_FBBMSEL_Pos) 	& EBU_BUSRCON2_FBBMSEL_Msk)		/*EBU Burst buf len => FETBLEN	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_BFSSS_Pos) 	& EBU_BUSRCON2_BFSSS_Msk)		/*EBU Read single stage sync	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_FDBKEN_Pos) 	& EBU_BUSRCON2_FDBKEN_Msk)		/*EBU Burst flash clk feedback	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON2_BFCMSEL_Pos) 	& EBU_BUSRCON2_BFCMSEL_Msk)		/*EBU Burst flash clk mode		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_NAA_Pos) 		& EBU_BUSRCON2_NAA_Msk)			/*EBU EN flash non-array access	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON2_ECSE_Pos) 		& EBU_BUSRCON2_ECSE_Msk)		/*EBU Early ChipSel=>sync burst	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON2_EBSE_Pos) 		& EBU_BUSRCON2_EBSE_Msk)		/*EBU Early #ADV for sync burst	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_DBA_Pos) 		& EBU_BUSRCON2_DBA_Msk)			/*EBU DIS burst addr. wrapping	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_WAITINV_Pos) 	& EBU_BUSRCON2_WAITINV_Msk)		/*EBU Reversed polarity at WAIT	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_BCGEN_Pos) 	& EBU_BUSRCON2_BCGEN_Msk)		/*EBU Byte control sig.(timing)	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON2_PORTW_Pos) 	& EBU_BUSRCON2_PORTW_Msk)		/*EBU Device addressing mode	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_WAIT_Pos) 		& EBU_BUSRCON2_WAIT_Msk)		/*EBU External WAIT control		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_AAP_Pos) 		& EBU_BUSRCON2_AAP_Msk)			/*EBU Async address phase		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON2_AGEN_Pos) 		& EBU_BUSRCON2_AGEN_Msk)		/*EBU Device type for region	rw*/ \
						);
						
	/*!< (@ 0x58008058) EBU Bus Configuration Register                         */
		EBU->BUSRCON3 =	(	((uint32_t)(0U  				<<  EBU_BUSRCON3_FETBLEN_Pos) 	& EBU_BUSRCON3_FETBLEN_Msk)		/*EBU Burst length (sync. dev.)	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_FBBMSEL_Pos) 	& EBU_BUSRCON3_FBBMSEL_Msk)		/*EBU Burst buf len => FETBLEN	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_BFSSS_Pos) 	& EBU_BUSRCON3_BFSSS_Msk)		/*EBU Read single stage sync	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_FDBKEN_Pos) 	& EBU_BUSRCON3_FDBKEN_Msk)		/*EBU Burst flash clk feedback	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON3_BFCMSEL_Pos) 	& EBU_BUSRCON3_BFCMSEL_Msk)		/*EBU Burst flash clk mode		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_NAA_Pos) 		& EBU_BUSRCON3_NAA_Msk)			/*EBU EN flash non-array access	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON3_ECSE_Pos) 		& EBU_BUSRCON3_ECSE_Msk)		/*EBU Early ChipSel=>sync burst	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON3_EBSE_Pos) 		& EBU_BUSRCON3_EBSE_Msk)		/*EBU Early #ADV for sync burst	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_DBA_Pos) 		& EBU_BUSRCON3_DBA_Msk)			/*EBU DIS burst addr. wrapping	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_WAITINV_Pos) 	& EBU_BUSRCON3_WAITINV_Msk)		/*EBU Reversed polarity at WAIT	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_BCGEN_Pos) 	& EBU_BUSRCON3_BCGEN_Msk)		/*EBU Byte control sig.(timing)	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRCON3_PORTW_Pos) 	& EBU_BUSRCON3_PORTW_Msk)		/*EBU Device addressing mode	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_WAIT_Pos) 		& EBU_BUSRCON3_WAIT_Msk)		/*EBU External WAIT control		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_AAP_Pos) 		& EBU_BUSRCON3_AAP_Msk)			/*EBU Async address phase		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRCON3_AGEN_Pos) 		& EBU_BUSRCON3_AGEN_Msk)		/*EBU Device type for region	rw*/ \
						);  

	/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	/*!< (@ 0x58008030) EBU Bus Write Configuration Register                   */
		EBU->BUSWCON0 =	(	((uint32_t)(0U  				<<  EBU_BUSWCON0_FETBLEN_Pos) 	& EBU_BUSWCON0_FETBLEN_Msk)		/*EBU Burst length (sync. dev.)	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON0_FBBMSEL_Pos) 	& EBU_BUSWCON0_FBBMSEL_Msk)		/*EBU Burst buf len => FETBLEN	rw*/| \
							/*((uint32_t)(0U  				<<  EBU_BUSWCON0_NAA_Pos) 		& EBU_BUSWCON0_NAA_Msk)			  EBU EN flash non-array access	r| \*/
							((uint32_t)(1U  				<<  EBU_BUSWCON0_ECSE_Pos) 		& EBU_BUSWCON0_ECSE_Msk)		/*EBU Early ChipSel=>sync burst	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWCON0_EBSE_Pos) 		& EBU_BUSWCON0_EBSE_Msk)		/*EBU Early #ADV for sync burst	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON0_WAITINV_Pos) 	& EBU_BUSWCON0_WAITINV_Msk)		/*EBU Reversed polarity at WAIT	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON0_BCGEN_Pos) 	& EBU_BUSWCON0_BCGEN_Msk)		/*EBU Byte control sig.(timing)	rw*/| \
							/*((uint32_t)(1U  				<<  EBU_BUSWCON0_PORTW_Pos) 	& EBU_BUSWCON0_PORTW_Msk)		  EBU Device addressing mode	r| \*/
							((uint32_t)(0U  				<<  EBU_BUSWCON0_WAIT_Pos) 		& EBU_BUSWCON0_WAIT_Msk)		/*EBU External WAIT control		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON0_AAP_Pos) 		& EBU_BUSWCON0_AAP_Msk)			/*EBU Async address phase		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON0_LOCKCS_Pos) 	& EBU_BUSWCON0_LOCKCS_Msk)		/*EBU Lock ChipSel				rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON0_AGEN_Pos) 		& EBU_BUSWCON0_AGEN_Msk)		/*EBU Device type for region	rw*/ \
						);                          
	 
	/*!< (@ 0x58008040) EBU Bus Write Configuration Register                   */
		EBU->BUSWCON1 =	(	((uint32_t)(0U  				<<  EBU_BUSWCON1_FETBLEN_Pos) 	& EBU_BUSWCON1_FETBLEN_Msk)		/*EBU Burst length (sync. dev.)	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON1_FBBMSEL_Pos) 	& EBU_BUSWCON1_FBBMSEL_Msk)		/*EBU Burst buf len => FETBLEN	rw*/| \
							/*((uint32_t)(0U  				<<  EBU_BUSWCON1_NAA_Pos) 		& EBU_BUSWCON1_NAA_Msk)			  EBU EN flash non-array access	r| \*/
							((uint32_t)(1U  				<<  EBU_BUSWCON1_ECSE_Pos) 		& EBU_BUSWCON1_ECSE_Msk)		/*EBU Early ChipSel=>sync burst	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWCON1_EBSE_Pos) 		& EBU_BUSWCON1_EBSE_Msk)		/*EBU Early #ADV for sync burst	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON1_WAITINV_Pos) 	& EBU_BUSWCON1_WAITINV_Msk)		/*EBU Reversed polarity at WAIT	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON1_BCGEN_Pos) 	& EBU_BUSWCON1_BCGEN_Msk)		/*EBU Byte control sig.(timing)	rw*/| \
							/*((uint32_t)(1U  				<<  EBU_BUSWCON1_PORTW_Pos) 	& EBU_BUSWCON1_PORTW_Msk)		  EBU Device addressing mode	r| \*/
							((uint32_t)(0U  				<<  EBU_BUSWCON1_WAIT_Pos) 		& EBU_BUSWCON1_WAIT_Msk)		/*EBU External WAIT control		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON1_AAP_Pos) 		& EBU_BUSWCON1_AAP_Msk)			/*EBU Async address phase		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON1_LOCKCS_Pos) 	& EBU_BUSWCON1_LOCKCS_Msk)		/*EBU Lock ChipSel				rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSWCON1_AGEN_Pos) 		& EBU_BUSWCON1_AGEN_Msk)		/*EBU Device type for region	rw*/ \
						);

	/*!< (@ 0x58008050) EBU Bus Write Configuration Register                   */
		EBU->BUSWCON2 =	(	((uint32_t)(0U  				<<  EBU_BUSWCON2_FETBLEN_Pos) 	& EBU_BUSWCON2_FETBLEN_Msk)		/*EBU Burst length (sync. dev.)	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON2_FBBMSEL_Pos) 	& EBU_BUSWCON2_FBBMSEL_Msk)		/*EBU Burst buf len => FETBLEN	rw*/| \
							/*((uint32_t)(0U  				<<  EBU_BUSWCON2_NAA_Pos) 		& EBU_BUSWCON2_NAA_Msk)			  EBU EN flash non-array access	r| \*/
							((uint32_t)(1U  				<<  EBU_BUSWCON2_ECSE_Pos) 		& EBU_BUSWCON2_ECSE_Msk)		/*EBU Early ChipSel=>sync burst	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWCON2_EBSE_Pos) 		& EBU_BUSWCON2_EBSE_Msk)		/*EBU Early #ADV for sync burst	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON2_WAITINV_Pos) 	& EBU_BUSWCON2_WAITINV_Msk)		/*EBU Reversed polarity at WAIT	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON2_BCGEN_Pos) 	& EBU_BUSWCON2_BCGEN_Msk)		/*EBU Byte control sig.(timing)	rw*/| \
							/*((uint32_t)(1U  				<<  EBU_BUSWCON2_PORTW_Pos) 	& EBU_BUSWCON2_PORTW_Msk)		  EBU Device addressing mode	r| \*/
							((uint32_t)(0U  				<<  EBU_BUSWCON2_WAIT_Pos) 		& EBU_BUSWCON2_WAIT_Msk)		/*EBU External WAIT control		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON2_AAP_Pos) 		& EBU_BUSWCON2_AAP_Msk)			/*EBU Async address phase		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON2_LOCKCS_Pos) 	& EBU_BUSWCON2_LOCKCS_Msk)		/*EBU Lock ChipSel				rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON2_AGEN_Pos) 		& EBU_BUSWCON2_AGEN_Msk)		/*EBU Device type for region	rw*/ \
						); 

	/*!< (@ 0x58008060) EBU Bus Write Configuration Register                   */
		EBU->BUSWCON3 =	(	((uint32_t)(0U  				<<  EBU_BUSWCON3_FETBLEN_Pos) 	& EBU_BUSWCON3_FETBLEN_Msk)		/*EBU Burst length (sync. dev.)	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON3_FBBMSEL_Pos) 	& EBU_BUSWCON3_FBBMSEL_Msk)		/*EBU Burst buf len => FETBLEN	rw*/| \
							/*((uint32_t)(0U  				<<  EBU_BUSWCON3_NAA_Pos) 		& EBU_BUSWCON3_NAA_Msk)			  EBU EN flash non-array access	r| \*/
							((uint32_t)(1U  				<<  EBU_BUSWCON3_ECSE_Pos) 		& EBU_BUSWCON3_ECSE_Msk)		/*EBU Early ChipSel=>sync burst	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWCON3_EBSE_Pos) 		& EBU_BUSWCON3_EBSE_Msk)		/*EBU Early #ADV for sync burst	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON3_WAITINV_Pos) 	& EBU_BUSWCON3_WAITINV_Msk)		/*EBU Reversed polarity at WAIT	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON3_BCGEN_Pos) 	& EBU_BUSWCON3_BCGEN_Msk)		/*EBU Byte control sig.(timing)	rw*/| \
							/*((uint32_t)(1U  				<<  EBU_BUSWCON3_PORTW_Pos) 	& EBU_BUSWCON3_PORTW_Msk)		  EBU Device addressing mode	r| \*/
							((uint32_t)(0U  				<<  EBU_BUSWCON3_WAIT_Pos) 		& EBU_BUSWCON3_WAIT_Msk)		/*EBU External WAIT control		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON3_AAP_Pos) 		& EBU_BUSWCON3_AAP_Msk)			/*EBU Async address phase		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON3_LOCKCS_Pos) 	& EBU_BUSWCON3_LOCKCS_Msk)		/*EBU Lock ChipSel				rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWCON3_AGEN_Pos) 		& EBU_BUSWCON3_AGEN_Msk)		/*EBU Device type for region	rw*/ \
						); 

	/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	/*!< (@ 0x5800802C) EBU Bus Read Access Parameter Register                 */
		EBU->BUSRAP0 =	(	((uint32_t)(1U  				<<  EBU_BUSRAP0_RDDTACS_Pos) 	& EBU_BUSRAP0_RDDTACS_Msk)		/*EBU Recov.cycles betw.regions	rw*/| \
							((uint32_t)(4U  				<<  EBU_BUSRAP0_RDRECOVC_Pos) 	& EBU_BUSRAP0_RDRECOVC_Msk)		/*EBU Recov.cycles after read	rw*/| \
							((uint32_t)(8U		  			<<  EBU_BUSRAP0_WAITRDC_Pos) 	& EBU_BUSRAP0_WAITRDC_Msk)		/*EBU Progr.wait state for read	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP0_DATAC_Pos) 		& EBU_BUSRAP0_DATAC_Msk)		/*EBU DataHold cyc.for RD(no FX)rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSRAP0_EXTCLOCK_Pos) 	& EBU_BUSRAP0_EXTCLOCK_Msk)		/*EBU Frequ.of ext. INT_CLK		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP0_EXTDATA_Pos) 	& EBU_BUSRAP0_EXTDATA_Msk)		/*EBU Extend. data (data=>BFCLK)rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP0_CMDDELAY_Pos) 	& EBU_BUSRAP0_CMDDELAY_Msk)		/*EBU Command delay cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP0_AHOLDC_Pos) 	& EBU_BUSRAP0_AHOLDC_Msk)		/*EBU Address hold cycles		rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSRAP0_ADDRC_Pos) 		& EBU_BUSRAP0_ADDRC_Msk)		/*EBU Address cycles			rw*/ \
						);                            

	/*!< (@ 0x5800803C) EBU Bus Read Access Parameter Register                 */
		EBU->BUSRAP1 =	(	((uint32_t)(1U  				<<  EBU_BUSRAP1_RDDTACS_Pos) 	& EBU_BUSRAP1_RDDTACS_Msk)		/*EBU Recov.cycles betw.regions	rw*/| \
							((uint32_t)(5U  				<<  EBU_BUSRAP1_RDRECOVC_Pos) 	& EBU_BUSRAP1_RDRECOVC_Msk)		/*EBU Recov.cycles after read	rw*/| \
							((uint32_t)(5U  				<<  EBU_BUSRAP1_WAITRDC_Pos) 	& EBU_BUSRAP1_WAITRDC_Msk)		/*EBU Progr.wait state for read	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP1_DATAC_Pos) 		& EBU_BUSRAP1_DATAC_Msk)		/*EBU DataHold cyc.for RD(no FX)rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSRAP1_EXTCLOCK_Pos) 	& EBU_BUSRAP1_EXTCLOCK_Msk)		/*EBU Frequ.of ext. INT_CLK		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP1_EXTDATA_Pos) 	& EBU_BUSRAP1_EXTDATA_Msk)		/*EBU Extend. data (data=>BFCLK)rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSRAP1_CMDDELAY_Pos) 	& EBU_BUSRAP1_CMDDELAY_Msk)		/*EBU Command delay cycles		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP1_AHOLDC_Pos) 	& EBU_BUSRAP1_AHOLDC_Msk)		/*EBU Address hold cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP1_ADDRC_Pos) 		& EBU_BUSRAP1_ADDRC_Msk)		/*EBU Address cycles			rw*/ \
						);

	/*!< (@ 0x5800804C) EBU Bus Read Access Parameter Register                 */
		EBU->BUSRAP2 =	(	((uint32_t)(1U  				<<  EBU_BUSRAP2_RDDTACS_Pos) 	& EBU_BUSRAP2_RDDTACS_Msk)		/*EBU Recov.cycles betw.regions	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP2_RDRECOVC_Pos) 	& EBU_BUSRAP2_RDRECOVC_Msk)		/*EBU Recov.cycles after read	rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSRAP2_WAITRDC_Pos) 	& EBU_BUSRAP2_WAITRDC_Msk)		/*EBU Progr.wait state for read	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP2_DATAC_Pos) 		& EBU_BUSRAP2_DATAC_Msk)		/*EBU DataHold cyc.for RD(no FX)rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSRAP2_EXTCLOCK_Pos) 	& EBU_BUSRAP2_EXTCLOCK_Msk)		/*EBU Frequ.of ext. INT_CLK		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP2_EXTDATA_Pos) 	& EBU_BUSRAP2_EXTDATA_Msk)		/*EBU Extend. data (data=>BFCLK)rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP2_CMDDELAY_Pos) 	& EBU_BUSRAP2_CMDDELAY_Msk)		/*EBU Command delay cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP2_AHOLDC_Pos) 	& EBU_BUSRAP2_AHOLDC_Msk)		/*EBU Address hold cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP2_ADDRC_Pos) 		& EBU_BUSRAP2_ADDRC_Msk)		/*EBU Address cycles			rw*/ \
						);

	/*!< (@ 0x5800805C) EBU Bus Read Access Parameter Register                 */
		EBU->BUSRAP3 =	(	((uint32_t)(1U  				<<  EBU_BUSRAP3_RDDTACS_Pos) 	& EBU_BUSRAP3_RDDTACS_Msk)		/*EBU Recov.cycles betw.regions	rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSRAP3_RDRECOVC_Pos) 	& EBU_BUSRAP3_RDRECOVC_Msk)		/*EBU Recov.cycles after read	rw*/| \
							((uint32_t)(8U  				<<  EBU_BUSRAP3_WAITRDC_Pos) 	& EBU_BUSRAP3_WAITRDC_Msk)		/*EBU Progr.wait state for read	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP3_DATAC_Pos) 		& EBU_BUSRAP3_DATAC_Msk)		/*EBU DataHold cyc.for RD(no FX)rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSRAP3_EXTCLOCK_Pos) 	& EBU_BUSRAP3_EXTCLOCK_Msk)		/*EBU Frequ.of ext. INT_CLK		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSRAP3_EXTDATA_Pos) 	& EBU_BUSRAP3_EXTDATA_Msk)		/*EBU Extend. data (data=>BFCLK)rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP3_CMDDELAY_Pos) 	& EBU_BUSRAP3_CMDDELAY_Msk)		/*EBU Command delay cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSRAP3_AHOLDC_Pos) 	& EBU_BUSRAP3_AHOLDC_Msk)		/*EBU Address hold cycles		rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSRAP3_ADDRC_Pos) 		& EBU_BUSRAP3_ADDRC_Msk)		/*EBU Address cycles			rw*/ \
						);

	/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	/*!< (@ 0x58008034) EBU Bus Write Access Parameter Register                */
		EBU->BUSWAP0 =	(	((uint32_t)(1U  				<<  EBU_BUSWAP0_WRDTACS_Pos) 	& EBU_BUSWAP0_WRDTACS_Msk)		/*EBU Recov.cycles betw.regions	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP0_WRRECOVC_Pos) 	& EBU_BUSWAP0_WRRECOVC_Msk)		/*EBU Recov.cycles after write	rw*/| \
							((uint32_t)(7U 					<<  EBU_BUSWAP0_WAITWRC_Pos) 	& EBU_BUSWAP0_WAITWRC_Msk)		/*EBU Progr.WaitState for write	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP0_DATAC_Pos) 		& EBU_BUSWAP0_DATAC_Msk)		/*EBU DataHold cyc.for write	rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSWAP0_EXTCLOCK_Pos) 	& EBU_BUSWAP0_EXTCLOCK_Msk)		/*EBU Frequ.of ext. BFCLKO pin	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWAP0_EXTDATA_Pos) 	& EBU_BUSWAP0_EXTDATA_Msk)		/*EBU Extend. data (data=>BFCLK)rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP0_CMDDELAY_Pos) 	& EBU_BUSWAP0_CMDDELAY_Msk)		/*EBU Command delay cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP0_AHOLDC_Pos) 	& EBU_BUSWAP0_AHOLDC_Msk)		/*EBU Address hold cycles		rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSWAP0_ADDRC_Pos) 		& EBU_BUSWAP0_ADDRC_Msk)		/*EBU Address cycles			rw*/ \
						);                           				                        

	/*!< (@ 0x58008044) EBU Bus Write Access Parameter Register                */
		EBU->BUSWAP1 =	(	((uint32_t)(1U  				<<  EBU_BUSWAP1_WRDTACS_Pos) 	& EBU_BUSWAP1_WRDTACS_Msk)		/*EBU Recov.cycles betw.regions	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP1_WRRECOVC_Pos) 	& EBU_BUSWAP1_WRRECOVC_Msk)		/*EBU Recov.cycles after write	rw*/| \
							((uint32_t)(3U 					<<  EBU_BUSWAP1_WAITWRC_Pos) 	& EBU_BUSWAP1_WAITWRC_Msk)		/*EBU Progr.WaitState for write	rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSWAP1_DATAC_Pos) 		& EBU_BUSWAP1_DATAC_Msk)		/*EBU DataHold cyc.for write	rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSWAP1_EXTCLOCK_Pos) 	& EBU_BUSWAP1_EXTCLOCK_Msk)		/*EBU Frequ.of ext. BFCLKO pin	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWAP1_EXTDATA_Pos) 	& EBU_BUSWAP1_EXTDATA_Msk)		/*EBU Extend. data (data=>BFCLK)rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWAP1_CMDDELAY_Pos) 	& EBU_BUSWAP1_CMDDELAY_Msk)		/*EBU Command delay cycles		rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWAP1_AHOLDC_Pos) 	& EBU_BUSWAP1_AHOLDC_Msk)		/*EBU Address hold cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP1_ADDRC_Pos) 		& EBU_BUSWAP1_ADDRC_Msk)		/*EBU Address cycles			rw*/ \
						); 
												  
	/*!< (@ 0x58008054) EBU Bus Write Access Parameter Register                */
		EBU->BUSWAP2 =	(	((uint32_t)(1U  				<<  EBU_BUSWAP2_WRDTACS_Pos) 	& EBU_BUSWAP2_WRDTACS_Msk)		/*EBU Recov.cycles betw.regions	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP2_WRRECOVC_Pos) 	& EBU_BUSWAP2_WRRECOVC_Msk)		/*EBU Recov.cycles after write	rw*/| \
							((uint32_t)(2U 					<<  EBU_BUSWAP2_WAITWRC_Pos) 	& EBU_BUSWAP2_WAITWRC_Msk)		/*EBU Progr.WaitState for write	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP2_DATAC_Pos) 		& EBU_BUSWAP2_DATAC_Msk)		/*EBU DataHold cyc.for write	rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSWAP2_EXTCLOCK_Pos) 	& EBU_BUSWAP2_EXTCLOCK_Msk)		/*EBU Frequ.of ext. BFCLKO pin	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWAP2_EXTDATA_Pos) 	& EBU_BUSWAP2_EXTDATA_Msk)		/*EBU Extend. data (data=>BFCLK)rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP2_CMDDELAY_Pos) 	& EBU_BUSWAP2_CMDDELAY_Msk)		/*EBU Command delay cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP2_AHOLDC_Pos) 	& EBU_BUSWAP2_AHOLDC_Msk)		/*EBU Address hold cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP2_ADDRC_Pos) 		& EBU_BUSWAP2_ADDRC_Msk)		/*EBU Address cycles			rw*/ \
						);

	/*!< (@ 0x58008064) EBU Bus Write Access Parameter Register                */
		EBU->BUSWAP3 =	(	((uint32_t)(1U  				<<  EBU_BUSWAP3_WRDTACS_Pos) 	& EBU_BUSWAP3_WRDTACS_Msk)		/*EBU Recov.cycles betw.regions	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP3_WRRECOVC_Pos) 	& EBU_BUSWAP3_WRRECOVC_Msk)		/*EBU Recov.cycles after write	rw*/| \
							((uint32_t)(6U 					<<  EBU_BUSWAP3_WAITWRC_Pos) 	& EBU_BUSWAP3_WAITWRC_Msk)		/*EBU Progr.WaitState for write	rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP3_DATAC_Pos) 		& EBU_BUSWAP3_DATAC_Msk)		/*EBU DataHold cyc.for write	rw*/| \
							((uint32_t)(3U  				<<  EBU_BUSWAP3_EXTCLOCK_Pos) 	& EBU_BUSWAP3_EXTCLOCK_Msk)		/*EBU Frequ.of ext. BFCLKO pin	rw*/| \
							((uint32_t)(0U  				<<  EBU_BUSWAP3_EXTDATA_Pos) 	& EBU_BUSWAP3_EXTDATA_Msk)		/*EBU Extend. data (data=>BFCLK)rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP3_CMDDELAY_Pos) 	& EBU_BUSWAP3_CMDDELAY_Msk)		/*EBU Command delay cycles		rw*/| \
							((uint32_t)(1U  				<<  EBU_BUSWAP3_AHOLDC_Pos) 	& EBU_BUSWAP3_AHOLDC_Msk)		/*EBU Address hold cycles		rw*/| \
							((uint32_t)(2U  				<<  EBU_BUSWAP3_ADDRC_Pos) 		& EBU_BUSWAP3_ADDRC_Msk)		/*EBU Address cycles			rw*/ \
						);                             

	/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	/*!< (@ 0x58008068) EBU SDRAM Control Register                             */
	//	EBU->SDRMCON =	(	((uint32_t)(0U  				<<  EBU_SDRMCON_CRAS_Pos) 		& EBU_SDRMCON_CRAS_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_CRFSH_Pos) 		& EBU_SDRMCON_CRFSH_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_CRSC_Pos) 		& EBU_SDRMCON_CRSC_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_CRP_Pos) 		& EBU_SDRMCON_CRP_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_AWIDTH_Pos) 	& EBU_SDRMCON_AWIDTH_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_CRCD_Pos) 		& EBU_SDRMCON_CRCD_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_CRC_Pos) 		& EBU_SDRMCON_CRC_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_ROWM_Pos) 		& EBU_SDRMCON_ROWM_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_BANKM_Pos) 		& EBU_SDRMCON_BANKM_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_CRCE_Pos) 		& EBU_SDRMCON_CRCE_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_CLKDIS_Pos) 	& EBU_SDRMCON_CLKDIS_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_PWR_MODE_Pos) 	& EBU_SDRMCON_PWR_MODE_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMCON_SDCMSEL_Pos) 	& EBU_SDRMCON_SDCMSEL_Msk)		/*EBU xxx  						rw*/ \
	//					);                            

	///*!< (@ 0x5800806C) EBU SDRAM Mode Register                                */
	//	EBU->SDRMOD =	(	((uint32_t)(0U  				<<  EBU_SDRMOD_BURSTL_Pos) 		& EBU_SDRMOD_BURSTL_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMOD_BTYP_Pos) 		& EBU_SDRMOD_BTYP_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMOD_CASLAT_Pos) 		& EBU_SDRMOD_CASLAT_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMOD_OPMODE_Pos) 		& EBU_SDRMOD_OPMODE_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMOD_COLDSTART_Pos) 	& EBU_SDRMOD_COLDSTART_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMOD_XOPM_Pos) 		& EBU_SDRMOD_XOPM_Msk)			/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMOD_XBA_Pos) 		& EBU_SDRMOD_XBA_Msk)			/*EBU xxx  						rw*/ \
	//					);                             

	///*!< (@ 0x58008070) EBU SDRAM Refresh Control Register                     */
	//	EBU->SDRMREF =	(	((uint32_t)(0U  				<<  EBU_SDRMREF_REFRESHC_Pos) 	& EBU_SDRMREF_REFRESHC_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_REFRESHR_Pos) 	& EBU_SDRMREF_REFRESHR_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_SELFREXST_Pos) 	& EBU_SDRMREF_SELFREXST_Msk)	/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_SELFREX_Pos) 	& EBU_SDRMREF_SELFREX_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_SELFRENST_Pos) 	& EBU_SDRMREF_SELFRENST_Msk)	/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_SELFREN_Pos) 	& EBU_SDRMREF_SELFREN_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_AUTOSELFR_Pos) 	& EBU_SDRMREF_AUTOSELFR_Msk)	/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_ERFSHC_Pos) 	& EBU_SDRMREF_ERFSHC_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_SELFREX_DLY_Pos)& EBU_SDRMREF_SELFREX_DLY_Msk)	/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_ARFSH_Pos) 		& EBU_SDRMREF_ARFSH_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRMREF_RES_DLY_Pos) 	& EBU_SDRMREF_RES_DLY_Msk)		/*EBU xxx  						rw*/ \
	//					);                            

	///*!< (@ 0x58008074) EBU SDRAM Status Register                              */
	//	EBU->SDRSTAT =	(	((uint32_t)(0U  				<<  EBU_SDRSTAT_REFERR_Pos) 	& EBU_SDRSTAT_REFERR_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRSTAT_SDRMBUSY_Pos) 	& EBU_SDRSTAT_SDRMBUSY_Msk)		/*EBU xxx  						rw*/| \
	//						((uint32_t)(0U  				<<  EBU_SDRSTAT_SDERR_Pos) 		& EBU_SDRSTAT_SDERR_Msk)		/*EBU xxx  						rw*/ \
	//					);                            

	/*------------------------------------------------------------------------------------------------------------------------------------------------------------*/
	//EBU->RESERVED0[1];

  }
}

