//****************************************************************************
// @Module        USIC0 Channel0 SPI Module (Memory)
// @Filename      U0C0_SPI_Memory.c
// @Project       XMC4500 TAS400 CPU
//----------------------------------------------------------------------------
//
// @Description   This file contains functions that use the CAN module.
//
//----------------------------------------------------------------------------
// @Date          13.05.2015 
//
//****************************************************************************

#include "basic_typedef.h"
#include "common_functions.h"
#include "U0C0_SPI_Memory.h"
#include "DMA/DMA.h"

#define CS_EEPROM1(change) ((change == 1) ? (PORT1->OUT |= 0x0001) : (PORT1->OUT &= ~(0x0001)))  // SEL0
#define CS_EEPROM2(change) ((change == 1) ? (PORT4->OUT |= 0x0040) : (PORT4->OUT &= ~(0x0040)))  // SEL2
#define CS_EEPROM3(change) ((change == 1) ? (PORT4->OUT |= 0x0020) : (PORT4->OUT &= ~(0x0020)))  // SEL3 

#define CS_FRAM1(change) ((change == 1) ? (PORT4->OUT |= 0x0010) : (PORT4->OUT &= ~(0x0010))) // SEL4
#define CS_FRAM2(change) ((change == 1) ? (PORT4->OUT |= 0x0008) : (PORT4->OUT &= ~(0x0008))) // SEL5

typedef struct spi_buffer_struct {
  UCHR *send_data_ptr;
  UINT send_maxlength;
	UINT akt_send_length;

  UCHR *rec_data_ptr;
  UINT rec_maxlength;
	UINT akt_rec_length;
} spi_buffer_struct;

UINT32 g_ui32SPI_lock = FALSE;

struct spi_buffer_struct spi_buffer;
struct spi_debug_struct spi_debug = {0};

UCHR spi_sendbuffer[SPI_SENDBUFFERSIZE];
UCHR spi_recbuffer [SPI_RECBUFFERSIZE];

static UCHR dummyWrite;
static UCHR dummyRead;
#define DMAMAXBLOCKLENGTH 4000

extern void U0C0_SSC_vInit(void);
void U0C0RecTransComplete (void);

// just to be called once at startup
void U0C0_SPI_vInit (void) {
	g_ui32SPI_lock = FALSE;

	CS_EEPROM1(1);  
  CS_EEPROM2(1);  
  CS_EEPROM3(1);  
  CS_FRAM1(1);
  CS_FRAM2(1);
	
  U0C0_SSC_vInit();
}

UINT32 spi_wait_for_finish() {
	while(g_ui32SPI_lock)
		;
	
	return 0;
}

//****************************************************************************
// @Function      UCHR write_to_spi (UCHR cs, void *cmd, UINT length)
// @Description   Ein Kommando an ein bestimmtes Gert am SPI-Bus schreiben
// @Returnvalue   UCHR 0..erfolgreich, >0 Fehler
// @Parameters    UCHR cs: Zu Schreibendes Gert
// @Parameters    void *cmd: Buffer
// @Parameters    UINT length: Bufferlnge
// @Date          05.10.2004
//****************************************************************************
UCHR write_to_spi (UCHR cs, void *cmd, UINT send_length, void *answ, UINT rec_length) {
  UINT buf_idx = 0;
	
  spi_buffer.send_data_ptr = (UCHR *) cmd;
  spi_buffer.send_maxlength = send_length;

  spi_buffer.rec_data_ptr = (UCHR *) answ;
  spi_buffer.rec_maxlength = rec_length;
  
	/* Alle CS deaktivieren                                                    */
  CS_EEPROM1(1);
  CS_EEPROM2(1);
  CS_EEPROM3(1);
  CS_FRAM1(1);
  CS_FRAM2(1);

	spi_buffer.akt_send_length = minimum_uint(spi_buffer.send_maxlength, DMAMAXBLOCKLENGTH);
	spi_buffer.send_maxlength -= spi_buffer.akt_send_length;
	buf_idx = 0;
	ProgramGPDMASpiTx (&spi_buffer.send_data_ptr[buf_idx], (void *) &USIC0_CH0->TBUF[0], spi_buffer.akt_send_length, SPITXSRCINC);

	// 1 byte dummy transfer, if USIC-Module TSIF Transmit Shift Indication Flag is set
	if ((USIC0_CH0->PSR_SSCMode & 0x1000UL) == 0) {
		g_ui32SPI_lock = TRUE;
		ProgramGPDMASpiRx ((void *)&USIC0_CH0->RBUF, &dummyRead, 1, SPIRXDSTNOCHANGE);
		StartGPDMASpiRx ();
		USIC0_CH0->TBUF[0] = 0;
		
		spi_wait_for_finish();
		spi_debug.ui32TxCnt += 1;
	}

	ProgramGPDMASpiRx ((void *)&USIC0_CH0->RBUF, &dummyRead, spi_buffer.akt_send_length, SPIRXDSTNOCHANGE);
	StartGPDMASpiRx ();
		
	/* Das richtige CS auswhlen                                               */
  if (cs == SPI_ADRESSE_EEPROM1) CS_EEPROM1(0);
  else if (cs == SPI_ADRESSE_EEPROM2) CS_EEPROM2(0);  
  else if (cs == SPI_ADRESSE_EEPROM3) CS_EEPROM3(0);  
  else if (cs == SPI_ADRESSE_FRAM1)   CS_FRAM1(0);    
  else if (cs == SPI_ADRESSE_FRAM2)   CS_FRAM2(0);    	
	else return 6;

	g_ui32SPI_lock = TRUE;
	StartGPDMASpiTx ();
	spi_wait_for_finish();
	
	spi_debug.ui32TxCnt += spi_buffer.akt_send_length;
	
	buf_idx += spi_buffer.akt_send_length;
	while (spi_buffer.send_maxlength > 0) {
		spi_buffer.akt_send_length = minimum_uint(spi_buffer.send_maxlength, DMAMAXBLOCKLENGTH);
		spi_buffer.send_maxlength -= spi_buffer.akt_send_length;
		
		g_ui32SPI_lock = TRUE;
		ProgramGPDMASpiTx (&spi_buffer.send_data_ptr[buf_idx], (void *) &USIC0_CH0->TBUF[0], spi_buffer.akt_send_length, SPITXSRCINC);
		ProgramGPDMASpiRx ((void *)&USIC0_CH0->RBUF, &dummyRead, spi_buffer.akt_send_length, SPIRXDSTNOCHANGE);
		
		StartGPDMASpiRx ();
		StartGPDMASpiTx ();
		spi_wait_for_finish();
		buf_idx += spi_buffer.akt_send_length;
		spi_debug.ui32TxCnt += spi_buffer.akt_send_length;
	}
	
	buf_idx = 0;
	while (spi_buffer.rec_maxlength > 0) {
		spi_buffer.akt_rec_length = minimum_uint(spi_buffer.rec_maxlength, DMAMAXBLOCKLENGTH);
		spi_buffer.rec_maxlength -= spi_buffer.akt_rec_length;
		dummyWrite = 0x00;
		
		g_ui32SPI_lock = TRUE;
		ProgramGPDMASpiTx (&dummyWrite             , (void *) &USIC0_CH0->TBUF[0], spi_buffer.akt_rec_length, SPITXSRCNOCHANGE);
		ProgramGPDMASpiRx ((void *)&USIC0_CH0->RBUF, &spi_buffer.rec_data_ptr[buf_idx] , spi_buffer.akt_rec_length, SPIRXDSTINC);
		StartGPDMASpiRx ();
		StartGPDMASpiTx ();
		
		spi_wait_for_finish();
		
		buf_idx += spi_buffer.akt_rec_length;
		spi_debug.ui32TxCnt += spi_buffer.akt_send_length;
	}

	/* Alle CS deaktivieren                                                    */
  CS_EEPROM1 (1);  
  CS_EEPROM2 (1);
  CS_EEPROM3 (1);  
  CS_FRAM1(1);
  CS_FRAM2(1);

  return 0;
}

void U0C0RecTransComplete (void) {
	spi_debug.empfangsinterrupts++;
  
	g_ui32SPI_lock = FALSE;
}

/*===========================================================================*/
/* RX und TX Interrupts
 *===========================================================================*/
void USIC0_0_IRQHandler (void) {
	if (USIC0_CH0->PSR & 0x1000UL) {
		// Do nothing
		USIC0_CH0->PSCR |= 0x1000UL;
	}
}
   
void USIC0_1_IRQHandler (void) {
	// Chip Bug USIC 007 Beide Interrupts mssen abgefragt werden
	// Alternate Receive Event
	if (USIC0_CH0->PSR & 0x8000UL) {
		USIC0_CH0->PSCR |= 0x8000UL;
	}
	// Receive Event
	if (USIC0_CH0->PSR & 0x4000UL) {
		USIC0_CH0->PSCR |= 0x4000UL;
	}
}	
