// Contains CPU Exception handling

#include "basic_typedef.h"
#include "fault_handler.h"

#pragma arm section rwdata="IRAM2_non_init_content",zidata="IRAM2_non_init_content"
	volatile stackframe_struct_t		g_stack_frame __attribute__((zero_init));
#pragma arm section rwdata,zidata // back to default

typedef enum enumSTACKREGS {
	esr_R0, 
	esr_R1, 
	esr_R2, 
	esr_R3, 
	esr_R12, 
	esr_LR, 
	esr_PC, 
	esr_PSR
} enumSTACKREGS_t;

void RSE_Softwarereset(void) {
	UINT32 ui32Idx = 0;
	UINT8 ui8LedVal = FALSE;
	
	set_linkled(TRUE);
	while(1) {
		ui32Idx++;
		if ((ui32Idx % 350000) == 0) {
			set_modemled(ui8LedVal);
			ui8LedVal = !ui8LedVal;
		}
	}
}

// Generic_Fault_Handler()
// @see Documentation and source for 'Developing a Generic Hard Fault handler for ARM Cortex-M3/Cortex-M4
// Niall Cooling / Feabhas Limited
// https://github.com/feabhas/CM3_Fault_Handler
// stack .. stack pointer to MSP or PSP
// err_type .. error code needed for SW_PANIC
void Generic_Fault_Handler (uint32_t stack[], uint32_t err_type) {
	volatile unsigned long _CFSR ;
  volatile unsigned long _HFSR ;
  volatile unsigned long _DFSR ;
  volatile unsigned long _AFSR ;
  volatile unsigned long _BFAR ;
  volatile unsigned long _MMAR ;
	
	g_stack_frame.stacked_r0  = stack[esr_R0];
	g_stack_frame.stacked_r1  = stack[esr_R1];
	g_stack_frame.stacked_r2  = stack[esr_R2];
	g_stack_frame.stacked_r3  = stack[esr_R3];
	g_stack_frame.stacked_r12 = stack[esr_R12];
	g_stack_frame.stacked_lr  = stack[esr_LR];
	g_stack_frame.stacked_pc  = stack[esr_PC];
	g_stack_frame.stacked_psr = stack[esr_PSR];
	
	// Configurable Fault Status Register
  // Consists of MMSR, BFSR and UFSR
  _CFSR = (*((volatile unsigned long *)(0xE000ED28))) ;

  // Hard Fault Status Register
  _HFSR = (*((volatile unsigned long *)(0xE000ED2C))) ;

  // Debug Fault Status Register
  _DFSR = (*((volatile unsigned long *)(0xE000ED30))) ;

  // Auxiliary Fault Status Register
  _AFSR = (*((volatile unsigned long *)(0xE000ED3C))) ;

  // Read the Fault Address Registers. These may not contain valid values.
  // Check BFARVALID/MMARVALID to see if they are valid values
  // MemManage Fault Address Register
  _MMAR = (*((volatile unsigned long *)(0xE000ED34))) ;
  // Bus Fault Address Register
  _BFAR = (*((volatile unsigned long *)(0xE000ED38))) ;
	
	/* BFAR: BusFault Address Register
		The BFAR contains the address of the location that generated a BusFault*/
	g_stack_frame.bus_fault_address = SCB->BFAR;
	
	/* MMFAR: MemManage Fault Address Register
		The MMFAR contains the address of the location that generated a MemManage fault.*/
	g_stack_frame.memmanage_fault_address = SCB->MMFAR;
	
	/* CFSR: Configurable Fault Status Register
		The CFSR indicates the cause of a MemManage fault, BusFault, or UsageFault.
		The flags in the MMFSR indicate the cause of memory access faults.*/
	g_stack_frame.cfsr = SCB->CFSR;
	
	// set breakpoint, if debugger is connected
//	if (CoreDebug->DHCSR & 1) { // check C_DEBUGEN == 1 -> Debugger Connected
//		__breakpoint (0); // halt program execution here
//	}
	
	_ISR_SW_PANIC(err_type);
	SCB->CFSR = 0;
}

// @see Joseph Yiu - The Definitive Guide to the ARM Cortex-M.. - p402
// LR R14 .. Link register value; in an ISR, LR is used as EXC_RETURN
__asm void NMI_Handler(void)
{
	TST lr, #4
	ITE EQ
	MRSEQ r0, MSP
	MRSNE r0, PSP
	MOVS  R1, #NMI_HANDLER
	B __cpp(Generic_Fault_Handler)
}

// @see Joseph Yiu - The Definitive Guide to the ARM Cortex-M.. - p402
// LR R14 .. Link register value; in an ISR, LR is used as EXC_RETURN
__asm void HardFault_Handler(void)
{
	TST lr, #4
	ITE EQ
	MRSEQ r0, MSP
	MRSNE r0, PSP
	MOVS  R1, #HARDFAULT_HANDLER
	B __cpp(Generic_Fault_Handler)
}

// Memory Management Fault: detects memory access violations to regions that are defined in the Memory
// Management Unit (MPU); for example code execution from a memory region with read/write access only.
// @see Joseph Yiu - The Definitive Guide to the ARM Cortex-M.. - p402
// LR R14 .. Link register value; in an ISR, LR is used as EXC_RETURN
__asm void MemManage_Handler(void)
{
	TST lr, #4
	ITE EQ
	MRSEQ r0, MSP
	MRSNE r0, PSP
	MOVS  R1, #MEMMANGE_HANDLER
	B __cpp(Generic_Fault_Handler)
}

// Bus Fault: detects memory access errors on instruction fetch, data read/write, interrupt vector fetch, and register
// stacking (save/restore) on interrupt (entry/exit).
// @see XMC4500 reference manual - Configurable Fault Status Register CFSR
// A BusFault is an exception that occurs because of a memory
// related fault for an instruction or data memory transaction. This
// might be from an error detected on a bus in the memory system.
// @see Joseph Yiu - The Definitive Guide to the ARM Cortex-M.. - p402
// LR R14 .. Link register value; in an ISR, LR is used as EXC_RETURN
__asm void BusFault_Handler(void)
{
	TST lr, #4
	ITE EQ
	MRSEQ r0, MSP
	MRSNE r0, PSP
	MOVS  R1, #BUSFAULTHANDLER
	B __cpp(Generic_Fault_Handler)
}

// Usage Fault: detects execution of undefined instructions, unaligned memory access for load/store multiple. When
// enabled, divide-by-zero and other unaligned memory accesses are also detected.
// @see Joseph Yiu - The Definitive Guide to the ARM Cortex-M.. - p402
// LR R14 .. Link register value; in an ISR, LR is used as EXC_RETURN
__asm void UsageFault_Handler(void)
{
	TST lr, #4
	ITE EQ
	MRSEQ r0, MSP
	MRSNE r0, PSP
	MOVS  R1, #USAGEFAULTHANDLER
	B __cpp(Generic_Fault_Handler)
}

// @see Joseph Yiu - The Definitive Guide to the ARM Cortex-M.. - p402
// LR R14 .. Link register value; in an ISR, LR is used as EXC_RETURN
// Call this function only from an ISR!
__asm void SW_Reset_Handler(UINT32 ui32PC, UINT32 ui32LR)
{
	MOV R2, R0
	MOV R3, R1
	
	TST lr, #4
	ITE EQ
	MRSEQ r0, MSP
	MRSNE r0, PSP

	MOVS  R1, #1
	
	B __cpp(Generic_Fault_Handler)
}

/*
void SVC_Handler()
{
	for (;;)
	{
		__NOP();
	}
}*/

// This ISR is marked as 12 .. Reserved for Debug
void DebugMon_Handler()
{
	/*for (;;)
	{
		__NOP();
	}*/
	_ISR_SW_PANIC(OTHER_CLASS_B_TRAP);
}
/*
void PendSV_Handler()
{
	for (;;)
	{
		__NOP();
	}
}*/

volatile UINT32 g_ui32SysTicks = 0;

//void SysTick_Handler()
void OS_Tick_Handler()
{
	g_ui32SysTicks++;
}
